@@ -180,6 +180,12 @@ pub mod wait_for_conditions;
 pub use self::wait_for_conditions::WaitForConditions;
 pub mod webhook_dto;
 pub use self::webhook_dto::WebhookDto;
+pub mod webhook_new_attachment_payload;
+pub use self::webhook_new_attachment_payload::WebhookNewAttachmentPayload;
+pub mod webhook_new_contact_payload;
+pub use self::webhook_new_contact_payload::WebhookNewContactPayload;
+pub mod webhook_new_email_payload;
+pub use self::webhook_new_email_payload::WebhookNewEmailPayload;
 pub mod webhook_projection;
 pub use self::webhook_projection::WebhookProjection;
 pub mod webhook_test_request;
